@@ -1,8 +1,8 @@
-import unittest
 import datetime
 import logging
-import socket
 import pkg_resources
+import socket
+import unittest
 from errormator_client import client, make_errormator_middleware
 from errormator_client.exceptions import get_current_traceback
 from errormator_client.logger import register_logging
@@ -12,13 +12,14 @@ from errormator_client.wsgi import ErrormatorWSGIWrapper
 fname = pkg_resources.resource_filename('errormator_client',
                                         'templates/default_template.ini')
 timing_conf = client.get_config(path_to_config=fname)
-for k,v in timing_conf.iteritems(): 
+for k, v in timing_conf.iteritems():
     if 'errormator.timing' in k:
         timing_conf[k] = 0.000001
 
 client.Client(config=timing_conf)
 from errormator_client.timing import local_timing
 
+
 def example_filter_callable(structure, section=None):
     return 'filtered-data'
 
@@ -47,12 +48,12 @@ TEST_ENVIRON = {
 'wsgi.multiprocess': False,
 'HTTP_ACCEPT_LANGUAGE': 'en-us,en;q=0.5',
 'HTTP_ACCEPT_ENCODING': 'gzip, deflate',
-'REMOTE_USER':'foo'
+'REMOTE_USER': 'foo'
 }
 
 REQ_START_TIME = datetime.datetime(2012, 9, 26, 18, 17, 54, 461254)
 REQ_END_TIME = datetime.datetime(2012, 9, 26, 18, 18, 4, 461259)
-SERVER_NAME = socket.getfqdn() # different on every machine
+SERVER_NAME = socket.getfqdn()  # different on every machine
 
 PARSED_REPORT_404 = {
                      'report_details': [{'username': '',
@@ -71,7 +72,7 @@ PARSED_REPORT_404 = {
                      'client': 'Python',
                      'http_status': 404}
 
-PARSED_REPORT_500 = {'traceback': u'Traceback (most recent call last):', #this will be different everywhere
+PARSED_REPORT_500 = {'traceback': u'Traceback (most recent call last):',  # this will be different everywhere
                      'report_details': [{'username': u'foo',
                                          'url': 'http://localhost:6543/test/error?aaa=1&bbb=2',
                                          'ip': '127.0.0.1',
@@ -118,6 +119,7 @@ PARSED_SLOW_REPORT = {
                       'client': 'Python',
                       'http_status': 200}
 
+
 class TestClientConfig(unittest.TestCase):
 
     def setUpClient(self, config={}):
@@ -128,7 +130,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertIsInstance(self.client, client.Client)
 
     def test_api_key(self):
-        config = {'errormator.api_key':"ABCD"}
+        config = {'errormator.api_key': "ABCD"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['api_key'],
                          config['errormator.api_key'])
@@ -139,7 +141,7 @@ class TestClientConfig(unittest.TestCase):
                          'https://api.errormator.com')
 
     def test_custom_server(self):
-        config = {'errormator.server_url':"http://foo.bar.com"}
+        config = {'errormator.server_url': "http://foo.bar.com"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['server_url'],
                          config['errormator.server_url'])
@@ -149,23 +151,22 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['enabled'], True)
 
     def test_disabled_client(self):
-        config = {'errormator':"false"}
+        config = {'errormator': "false"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['enabled'], False)
 
     def test_server_name(self):
-        config = {'errormator.server_name':"some_name"}
+        config = {'errormator.server_name': "some_name"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['server_name'],
                          config['errormator.server_name'])
 
     def test_default_server_name(self):
-        import socket
         self.setUpClient()
         self.assertEqual(self.client.config['server_name'], socket.getfqdn())
 
     def test_client_name(self):
-        config = {'errormator.client':"pythonX"}
+        config = {'errormator.client': "pythonX"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['client'],
                          config['errormator.client'])
@@ -179,12 +180,12 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['timeout'], 10)
 
     def test_timeout(self):
-        config = {'errormator.timeout':"5"}
+        config = {'errormator.timeout': "5"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['timeout'], 5)
 
     def test_reraise_exceptions(self):
-        config = {'errormator.reraise_exceptions':"false"}
+        config = {'errormator.reraise_exceptions': "false"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['reraise_exceptions'], False)
 
@@ -197,7 +198,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['slow_requests'], True)
 
     def test_disabled_slow_requests(self):
-        config = {'errormator.reraise_exceptions':"false"}
+        config = {'errormator.reraise_exceptions': "false"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['reraise_exceptions'], False)
 
@@ -207,13 +208,13 @@ class TestClientConfig(unittest.TestCase):
                          datetime.timedelta(seconds=1))
 
     def test_custom_slow_request_time(self):
-        config = {'errormator.slow_request.time':"2"}
+        config = {'errormator.slow_request_time': "2"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['slow_request_time'],
                          datetime.timedelta(seconds=2))
 
     def test_too_low_custom_slow_request_time(self):
-        config = {'errormator.slow_request.time':"0.001"}
+        config = {'errormator.slow_request_time': "0.001"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['slow_request_time'],
                          datetime.timedelta(seconds=0.01))
@@ -223,7 +224,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['logging'], True)
 
     def test_custom_logging(self):
-        config = {'errormator.logging':"false"}
+        config = {'errormator.logging': "false"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['logging'], False)
 
@@ -232,7 +233,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['logging_on_error'], False)
 
     def test_custom_logging_on_error(self):
-        config = {'errormator.logging_on_error':"true"}
+        config = {'errormator.logging_on_error': "true"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['logging_on_error'], True)
 
@@ -241,7 +242,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['report_404'], False)
 
     def test_custom_report_404r(self):
-        config = {'errormator.report_404':"true"}
+        config = {'errormator.report_404': "true"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['report_404'], True)
 
@@ -250,7 +251,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['report_errors'], True)
 
     def test_custom_report_errors(self):
-        config = {'errormator.report_errors':"false"}
+        config = {'errormator.report_errors': "false"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['report_errors'], False)
 
@@ -260,13 +261,13 @@ class TestClientConfig(unittest.TestCase):
                          datetime.timedelta(seconds=5))
 
     def test_custom_buffer_flush_interval(self):
-        config = {'errormator.buffer_flush_interval':"10"}
+        config = {'errormator.buffer_flush_interval': "10"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['buffer_flush_interval'],
                          datetime.timedelta(seconds=10))
 
     def test_custom_small_buffer_flush_interval(self):
-        config = {'errormator.buffer_flush_interval':"0"}
+        config = {'errormator.buffer_flush_interval': "0"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['buffer_flush_interval'],
                          datetime.timedelta(seconds=1))
@@ -276,7 +277,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['force_send'], False)
 
     def test_custom_force_send(self):
-        config = {'errormator.force_send':"1"}
+        config = {'errormator.force_send': "1"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['force_send'], True)
 
@@ -287,7 +288,7 @@ class TestClientConfig(unittest.TestCase):
                  'session'])
 
     def test_custom_request_keys_blacklist(self):
-        config = {'errormator.request_keys_blacklist':"aa,bb,cc"}
+        config = {'errormator.request_keys_blacklist': "aa,bb,cc"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['request_keys_blacklist'],
                          ['password', 'passwd', 'pwd', 'auth_tkt', 'secret',
@@ -300,7 +301,7 @@ class TestClientConfig(unittest.TestCase):
                  'HTTP_REFERER'])
 
     def test_custom_environ_keys_whitelist(self):
-        config = {'errormator.environ_keys_whitelist':"aa,bb,cc"}
+        config = {'errormator.environ_keys_whitelist': "aa,bb,cc"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['environ_keys_whitelist'],
                 ['REMOTE_USER', 'REMOTE_ADDR', 'SERVER_NAME', 'CONTENT_TYPE',
@@ -312,7 +313,7 @@ class TestClientConfig(unittest.TestCase):
                 ['errormator_client.client'])
 
     def test_custom_log_namespace_blacklist(self):
-        config = {'errormator.log_namespace_blacklist':"aa,bb,cc.dd"}
+        config = {'errormator.log_namespace_blacklist': "aa,bb,cc.dd"}
         self.setUpClient(config)
         self.assertEqual(self.client.config['log_namespace_blacklist'],
                 ['aa', 'bb', 'cc.dd'])
@@ -322,12 +323,13 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.filter_callable, self.client.data_filter)
 
     def test_bad_filter_callable(self):
-        config = {'errormator.filter_callable':"foo.bar.baz:callable_name"}
+        config = {'errormator.filter_callable': "foo.bar.baz:callable_name"}
         self.setUpClient(config)
         self.assertEqual(self.client.filter_callable, self.client.data_filter)
 
     def test_custom_filter_callable(self):
-        config = {'errormator.filter_callable':"errormator_client.tests:example_filter_callable"}
+        config = {'errormator.filter_callable':
+                  "errormator_client.tests:example_filter_callable"}
         self.setUpClient(config)
         self.assertEqual(self.client.filter_callable.__name__,
                          example_filter_callable.__name__)
@@ -337,7 +339,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(hasattr(self.client, 'log_handler'), True)
 
     def test_custom_logging_handler_present(self):
-        config = {'errormator.logging':"false"}
+        config = {'errormator.logging': "false"}
         self.setUpClient(config)
         self.assertEqual(hasattr(self.client, 'log_handler'), False)
 
@@ -346,7 +348,7 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.log_handler.level, logging.WARNING)
 
     def test_custom_logging_handler_level(self):
-        config = {'errormator.logging.level':"CRITICAL"}
+        config = {'errormator.logging.level': "CRITICAL"}
         self.setUpClient(config)
         self.assertEqual(self.client.log_handler.level, logging.CRITICAL)
 
@@ -355,30 +357,33 @@ class TestClientConfig(unittest.TestCase):
         self.assertEqual(self.client.config['timing'], {})
 
     def test_timing_config_disable(self):
-        config = {'errormator.timing.dbapi2_psycopg2':'false'}
+        config = {'errormator.timing.dbapi2_psycopg2': 'false'}
         self.setUpClient(config)
-        self.assertEqual(self.client.config['timing']['dbapi2_psycopg2'], False)
+        self.assertEqual(self.client.config['timing']['dbapi2_psycopg2'],
+                         False)
 
     def test_timing_config_custom(self):
-        config = {'errormator.timing.dbapi2_psycopg2':'5'}
+        config = {'errormator.timing.dbapi2_psycopg2': '5'}
         self.setUpClient(config)
         self.assertEqual(self.client.config['timing']['dbapi2_psycopg2'], 5)
 
     def test_timing_config_mixed(self):
-        config = {'errormator.timing.dbapi2_psycopg2':'5',
-                  'errormator.timing':{'urllib':11, 'dbapi2_oursql':6}
+        config = {'errormator.timing.dbapi2_psycopg2': '5',
+                  'errormator.timing': {'urllib': 11, 'dbapi2_oursql': 6}
                   }
         self.setUpClient(config)
         self.assertEqual(self.client.config['timing']['dbapi2_psycopg2'], 5)
         self.assertEqual(self.client.config['timing']['dbapi2_oursql'], 6)
         self.assertEqual(self.client.config['timing']['urllib'], 11)
 
+
 def generate_error():
     pass
 
+
 class TestClientSending(unittest.TestCase):
 
-    def setUpClient(self, config={'errormator.api_key':'blargh!'}):
+    def setUpClient(self, config={'errormator.api_key': 'blargh!'}):
         self.client = client.Client(config)
 
     def test_check_if_deliver_false(self):
@@ -392,7 +397,7 @@ class TestClientSending(unittest.TestCase):
     def test_send_error_failure_queue(self):
         self.setUpClient()
         self.client.py_report(TEST_ENVIRON, http_status=404)
-        result = self.client.submit_data()
+        self.client.submit_data()
         self.assertEqual(self.client.report_queue, [])
 
     def test_send_error_failure(self):
@@ -400,13 +405,14 @@ class TestClientSending(unittest.TestCase):
         self.client.py_report(TEST_ENVIRON, http_status=404)
         result = self.client.submit_data()
         self.assertEqual(result['reports'], False)
-        
+
     def test_send_error_io(self):
         self.setUpClient()
         self.client.py_report(TEST_ENVIRON, http_status=404)
         result = self.client.submit_data()
         self.assertEqual(result['reports'], False)
 
+
 class TestErrorParsing(unittest.TestCase):
     def setUpClient(self, config={}):
         self.client = client.Client(config)
@@ -433,9 +439,11 @@ class TestErrorParsing(unittest.TestCase):
                                               ignore_system_exceptions=True)
         self.client.py_report(TEST_ENVIRON, traceback=traceback,
                               http_status=500)
-        self.client.report_queue[0]['traceback'] = 'Traceback (most recent call last):'
+        self.client.report_queue[0]['traceback'] = \
+                                    'Traceback (most recent call last):'
         self.assertEqual(self.client.report_queue[0], PARSED_REPORT_500)
 
+
 class TestLogs(unittest.TestCase):
     def setUpClient(self, config={}):
         self.client = client.Client(config)
@@ -448,7 +456,7 @@ class TestLogs(unittest.TestCase):
         self.client.py_log(TEST_ENVIRON, records=handler.get_records())
         fake_log = {'log_level': 'CRITICAL',
                      'namespace': 'testing',
-                     'server': 'test-foo', # this will be different everywhere
+                     'server': 'test-foo',  # this will be different everywhere
                      'request_id': None,
                      'date': '2012-08-13T21:20:37.418.307066',
                      'message': 'test entry'}
@@ -457,6 +465,7 @@ class TestLogs(unittest.TestCase):
         self.client.log_queue[0]['server'] = fake_log['server']
         self.assertEqual(self.client.log_queue[0], fake_log)
 
+
 class TestSlowReportParsing(unittest.TestCase):
     def setUpClient(self, config={}):
         self.client = client.Client(config)
@@ -468,35 +477,36 @@ class TestSlowReportParsing(unittest.TestCase):
                                    end_time=REQ_END_TIME)
         self.assertEqual(self.client.slow_report_queue[0], PARSED_SLOW_REPORT)
 
+
 class TestMakeMiddleware(unittest.TestCase):
-    
+
     def test_make_middleware(self):
         def app(environ, start_response):
             start_response('200 OK', [('content-type', 'text/html')])
             return ['Hello world!']
-        app = make_errormator_middleware(app, {'errormator':True})
+        app = make_errormator_middleware(app, {'errormator': True})
         self.assertTrue(isinstance(app, ErrormatorWSGIWrapper))
 
     def test_make_middleware_disabled(self):
         def app(environ, start_response):
             start_response('200 OK', [('content-type', 'text/html')])
             return ['Hello world!']
-        app = make_errormator_middleware(app, {})        
+        app = make_errormator_middleware(app, {})
         self.assertFalse(isinstance(app, ErrormatorWSGIWrapper))
 
 
 class TestTimingHTTPLibs(unittest.TestCase):
-    
+
     def setUpClient(self, config={}):
         self.client = client.Client(config)
-        
+
     def setUp(self):
         self.setUpClient(timing_conf)
-    
+
     def test_urllib_URLOpener_open(self):
         import urllib
         opener = urllib.URLopener()
-        f = opener.open("http://www.ubuntu.com/")
+        opener.open("http://www.ubuntu.com/")
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
 
@@ -515,13 +525,13 @@ class TestTimingHTTPLibs(unittest.TestCase):
     def test_urllib3(self):
         import urllib3
         http = urllib3.PoolManager()
-        r = http.request('GET', "http://www.ubuntu.com/")
+        http.request('GET', "http://www.ubuntu.com/")
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
-        
+
     def test_requests(self):
         import requests
-        r = requests.get("http://www.ubuntu.com/")
+        requests.get("http://www.ubuntu.com/")
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
 
@@ -532,15 +542,16 @@ class TestTimingHTTPLibs(unittest.TestCase):
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
 
+
 class TestDBApi2Drivers(unittest.TestCase):
-    
+
     def setUpClient(self, config={}):
         self.client = client.Client(config)
-    
+
     def setUp(self):
         self.setUpClient(timing_conf)
-        self.stmt = '''SELECT 1+2+3 as result''' 
-    
+        self.stmt = '''SELECT 1+2+3 as result'''
+
     def test_sqlite(self):
         try:
             import sqlite3
@@ -554,7 +565,7 @@ class TestDBApi2Drivers(unittest.TestCase):
         conn.close()
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
-    
+
     def test_psycopg2(self):
         try:
             import psycopg2
@@ -569,13 +580,14 @@ class TestDBApi2Drivers(unittest.TestCase):
         conn.close()
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
-        
+
     def test_pg8000(self):
         try:
             import pg8000
         except ImportError:
             return
-        conn = pg8000.DBAPI.connect(host="localhost", user="test", password="test")
+        conn = pg8000.DBAPI.connect(host="localhost", user="test",
+                                    password="test")
         c = conn.cursor()
         c.execute(self.stmt)
         c.fetchone()
@@ -583,7 +595,7 @@ class TestDBApi2Drivers(unittest.TestCase):
         conn.close()
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
-        
+
     def test_postgresql(self):
         try:
             import postgresql
@@ -653,13 +665,13 @@ class TestDBApi2Drivers(unittest.TestCase):
 
 
 class TestMako(unittest.TestCase):
-   
+
     def setUpClient(self, config={}):
         self.client = client.Client(timing_conf)
-        
+
     def setUp(self):
         self.setUpClient(timing_conf)
-   
+
     def test_render(self):
         try:
             import mako
@@ -669,9 +681,8 @@ class TestMako(unittest.TestCase):
         <%
         import time
         time.sleep(0.01)
-        %> 
+        %>
         xxxxx ${1+2} yyyyyy
-        
         ''')
         template.render()
         result = local_timing._errormator.get_slow_calls()
@@ -686,38 +697,37 @@ class TestMako(unittest.TestCase):
         <%
         import time
         time.sleep(0.01)
-        %> 
+        %>
         xxxxx ${1+2} yyyyyy
-        
         ''')
         template.render_unicode()
         result = local_timing._errormator.get_slow_calls()
-        self.assertEqual(len(result), 1)        
+        self.assertEqual(len(result), 1)
 
     def test_template_lookup(self):
         try:
-            import mako
+            from mako.lookup import TemplateLookup
         except ImportError:
             return
-        from mako.lookup import TemplateLookup
         lookup = TemplateLookup()
         lookup.put_string("base.html", '''
         <%
         import time
         time.sleep(0.01)
-        %> 
+        %>
             <html><body></body></html>
         ''')
         template = lookup.get_template("base.html")
         template.render_unicode()
         result = local_timing._errormator.get_slow_calls()
-        self.assertEqual(len(result), 1)     
+        self.assertEqual(len(result), 1)
+
 
 class TestJinja2(unittest.TestCase):
-   
+
     def setUpClient(self, config={}):
         self.client = client.Client(timing_conf)
-   
+
     def test_render(self):
         try:
             import jinja2
@@ -732,14 +742,15 @@ class TestJinja2(unittest.TestCase):
         result = local_timing._errormator.get_slow_calls()
         self.assertEqual(len(result), 1)
 
+
 class TestDjangoTemplates(unittest.TestCase):
-   
+
     def setUpClient(self, config={}):
         self.client = client.Client(config)
-        
+
     def setUp(self):
         self.setUpClient(timing_conf)
-   
+
     def test_render(self):
         try:
             from django import template
@@ -749,7 +760,7 @@ class TestDjangoTemplates(unittest.TestCase):
         settings.configure(TEMPLATE_DIRS=("/whatever/templates",))
         import time
         ctx = template.Context()
-        ctx.update({'time':lambda :time.sleep(0.06)})
+        ctx.update({'time': lambda: time.sleep(0.06)})
         template = template.Template('''
         xxxxx {{ time }} yyyyyy
         ''')
