@@ -1,18 +1,20 @@
 from errormator_client.utils import import_module, deco_func_or_method
 from errormator_client.timing import time_trace, import_from_module, _e_trace
 
+
 def add_timing(min_duration=0.15):
     module = import_module('mako')
     if not module:
         return
-    
+
     from mako import template
-    
+
     def gather_template(template, *args, **kwargs):
-        return {'type':'template',
-                'statement':'render_mako',
-                'parameters':''}
-        
+        return {'type': 'tmpl',
+                'subtype': 'mako',
+                'statement': 'render',
+                'parameters': ''}
+
     if hasattr(template.Template, '_e_attached_wrapper'):
         return
     deco_func_or_method(template, 'Template.render', time_trace,
