@@ -4,7 +4,7 @@ from errormator_client.timing import time_trace
 import logging
 
 to_decorate = ['count', 'create_index', 'distinct', 'drop', 'drop_index',
-               'drop_indexes', 'ensure_index', 'find','find_one',
+               'drop_indexes', 'ensure_index', 'find', 'find_one',
                'find_and_modify' 'group', 'index_information',
                'inline_map_reduce', 'insert', 'map_reduce', 'options',
                'reindex', 'remove', 'rename', 'save', 'update']
@@ -15,11 +15,13 @@ def add_timing(min_duration=0.3):
     if not module:
         return
     logging.warning('mongodb timing is currently experimental')
-        
+
     from pymongo.collection import Collection
+
     def general_factory(slow_call_name):
         def gather_args(self, *args, **kwargs):
-            return {'type':'mongo_nosql', 'statement':slow_call_name}
+            return {'type': 'nosql', 'subtype': 'mongo',
+                    'statement': slow_call_name}
         return gather_args
 
     for m in to_decorate:
